@@ -60,15 +60,9 @@
 #include "dlt_types.h"
 
 #define DLT_OFFLINETRACE_FILENAME_BASE "dlt_offlinetrace"
-#define DLT_OFFLINETRACE_FILENAME_DELI "."
+#define DLT_OFFLINETRACE_FILENAME_INDEX_DELI "."
+#define DLT_OFFLINETRACE_FILENAME_TIMESTAMP_DELI "_"
 #define DLT_OFFLINETRACE_FILENAME_EXT  ".dlt"
-#define DLT_OFFLINETRACE_INDEX_MAX_SIZE 10
-#define DLT_OFFLINETRACE_FILENAME_TO_COMPARE "dlt_offlinetrace_"
-/* "dlt_offlinetrace.4294967295.dlt" -> MAX 32byte include NULL terminate */
-#define DLT_OFFLINETRACE_FILENAME_MAX_SIZE   (sizeof(DLT_OFFLINETRACE_FILENAME_BASE) + \
-                                              sizeof(DLT_OFFLINETRACE_FILENAME_DELI) + \
-                                              DLT_OFFLINETRACE_INDEX_MAX_SIZE + \
-                                              sizeof(DLT_OFFLINETRACE_FILENAME_EXT) + 1)
 
 typedef struct
 {
@@ -134,7 +128,7 @@ extern DltReturnValue dlt_offline_trace_write(DltOfflineTrace *trace,
  * Get size of currently used offline trace buffer
  * @return size in bytes
  */
-extern unsigned long dlt_offline_trace_get_total_size(DltOfflineTrace *trace);
+extern ssize_t dlt_offline_trace_get_total_size(DltOfflineTrace *trace);
 
 /**
  * Provides info about the offline logs storage directory
@@ -149,10 +143,12 @@ unsigned int dlt_offline_trace_storage_dir_info(char *path, char *file_name, cha
 /**
  * creates filename with index
  * @param log_file_name file name created with index
+ * @param length the maximum length of the log_file_name
  * @param name filename base
  * @param idx index to be used for file name creation
  */
-void dlt_offline_trace_file_name(char *log_file_name, char *name, unsigned int idx);
+void dlt_offline_trace_file_name(char *log_file_name, size_t length,
+                                 char *name, unsigned int idx);
 
 /**
  * generates index for log file name
