@@ -282,35 +282,29 @@ int main(int argc, char *argv[])
 {
     DltReceiveData dltdata;
     int c;
+    int ret;
     int index;
     char *endptr = NULL;
     struct timespec ts;
 
     /* Initialize dltdata */
-    dltdata.vflag = 0;
-    dltdata.yflag = 0;
-    dltdata.evalue = 0;
-    dltdata.bvalue = 0;
-
-    dltdata.avalue = 0;
-    dltdata.cvalue = 0;
-    dltdata.svalue = 0;
-    dltdata.mvalue = 0;
-    dltdata.xvalue = 0;
-    dltdata.tvalue = 1000;
-    dltdata.lvalue = DLT_INVALID_LOG_LEVEL;
-    dltdata.rvalue = DLT_INVALID_TRACE_STATUS;
-    dltdata.dvalue = -1;
-    dltdata.fvalue = -1;
-    dltdata.ivalue = -1;
-    dltdata.oflag = -1;
-    dltdata.gflag = -1;
-    dltdata.jvalue = 0;
-    dltdata.kvalue = 0;
+    dltdata = (DltReceiveData) {
+        .tvalue = 1000,
+        .lvalue = DLT_INVALID_LOG_LEVEL,
+        .rvalue = DLT_INVALID_TRACE_STATUS,
+        .dvalue = -1,
+        .fvalue = -1,
+        .ivalue = -1,
+        .oflag = -1,
+        .gflag = -1,
+    };
 
     /* Fetch command line arguments */
     opterr = 0;
 
+    /* Default return value */
+    ret = 0;
+
     while ((c = getopt (argc, argv, "vhye:b:a:c:s:m:x:t:l:r:d:f:i:ogjku")) != -1)
         switch (c) {
         case 'v':
@@ -383,7 +377,7 @@ int main(int argc, char *argv[])
         }
         case 'l':
         {
-            dltdata.lvalue = strtol(optarg, &endptr, 10);
+            dltdata.lvalue = (int) strtol(optarg, &endptr, 10);
 
             if ((dltdata.lvalue < DLT_LOG_DEFAULT) || (dltdata.lvalue > DLT_LOG_VERBOSE)) {
                 fprintf (stderr, "invalid log level, supported log level 0-6\n");
@@ -394,7 +388,7 @@ int main(int argc, char *argv[])
         }
         case 'r':
         {
-            dltdata.rvalue = strtol(optarg, &endptr, 10);
+            dltdata.rvalue = (int) strtol(optarg, &endptr, 10);
 
             if ((dltdata.rvalue < DLT_TRACE_STATUS_DEFAULT) || (dltdata.rvalue > DLT_TRACE_STATUS_ON)) {
                 fprintf (stderr, "invalid trace status, supported trace status -1, 0, 1\n");
@@ -558,10 +552,12 @@ int main(int argc, char *argv[])
             if (dlt_client_send_inject_msg(&g_dltclient,
                                            dltdata.avalue,
                                            dltdata.cvalue,
-                                           dltdata.svalue,
+                                           (uint32_t) dltdata.svalue,
                                            (uint8_t *)dltdata.mvalue,
-                                           strlen(dltdata.mvalue)) != DLT_RETURN_OK)
+                                           (uint32_t) strlen(dltdata.mvalue)) != DLT_RETURN_OK) {
                 fprintf(stderr, "ERROR: Could not send inject message\n");
+                ret = -1;
+            }
         }
         else if (dltdata.xvalue && dltdata.avalue && dltdata.cvalue)
         {
@@ -580,9 +576,11 @@ int main(int argc, char *argv[])
             if (dlt_client_send_inject_msg(&g_dltclient,
                                            dltdata.avalue,
                                            dltdata.cvalue,
-                                           dltdata.svalue,
-                                           buffer, size) != DLT_RETURN_OK)
+                                           (uint32_t) dltdata.svalue,
+                                            buffer, (uint32_t)size) != DLT_RETURN_OK) {
                 fprintf(stderr, "ERROR: Could not send inject message\n");
+                ret = -1;
+            }
         }
         else if (dltdata.lvalue != DLT_INVALID_LOG_LEVEL)  /*&& dltdata.avalue && dltdata.cvalue)*/
         {
@@ -593,8 +591,10 @@ int main(int argc, char *argv[])
                 }
 
                 if (0 != dlt_client_send_all_log_level(&g_dltclient,
-                                                       dltdata.lvalue))
+                                                       (uint8_t) dltdata.lvalue)) {
                     fprintf(stderr, "ERROR: Could not send log level\n");
+                    ret = -1;
+                }
             }
             else {
                 /* log level */
@@ -609,8 +609,10 @@ int main(int argc, char *argv[])
                 if (0 != dlt_client_send_log_level(&g_dltclient,
                                                    dltdata.avalue,
                                                    dltdata.cvalue,
-                                                   dltdata.lvalue))
+                                                   (uint8_t) dltdata.lvalue)) {
                     fprintf(stderr, "ERROR: Could not send log level\n");
+                    ret = -1;
+                }
             }
         }
         else if (dltdata.rvalue != DLT_INVALID_TRACE_STATUS)
@@ -622,8 +624,10 @@ int main(int argc, char *argv[])
                 }
 
                 if (0 != dlt_client_send_all_trace_status(&g_dltclient,
-                                                          dltdata.rvalue))
+                                                          (uint8_t) dltdata.rvalue)) {
                     fprintf(stderr, "ERROR: Could not send trace status\n");
+                    ret = -1;
+                }
             }
             else {
                 /* trace status */
@@ -638,8 +642,10 @@ int main(int argc, char *argv[])
                 if (0 != dlt_client_send_trace_status(&g_dltclient,
                                                       dltdata.avalue,
                                                       dltdata.cvalue,
-                                                      dltdata.rvalue))
+                                                      (uint8_t) dltdata.rvalue)) {
                     fprintf(stderr, "ERROR: Could not send trace status\n");
+                    ret = -1;
+                }
             }
         }
         else if (dltdata.dvalue != -1)
@@ -649,8 +655,10 @@ int main(int argc, char *argv[])
             printf("Loglevel: %d\n", dltdata.dvalue);
 
             /* send control message in*/
-            if (dlt_client_send_default_log_level(&g_dltclient, dltdata.dvalue) != DLT_RETURN_OK)
+            if (dlt_client_send_default_log_level(&g_dltclient, (uint8_t) dltdata.dvalue) != DLT_RETURN_OK) {
                 fprintf (stderr, "ERROR: Could not send default log level\n");
+                ret = -1;
+            }
         }
         else if (dltdata.fvalue != -1)
         {
@@ -659,8 +667,10 @@ int main(int argc, char *argv[])
             printf("TraceStatus: %d\n", dltdata.fvalue);
 
             /* send control message in*/
-            if (dlt_client_send_default_trace_status(&g_dltclient, dltdata.fvalue) != DLT_RETURN_OK)
+            if (dlt_client_send_default_trace_status(&g_dltclient, (uint8_t) dltdata.fvalue) != DLT_RETURN_OK) {
                 fprintf (stderr, "ERROR: Could not send default trace status\n");
+                ret = -1;
+            }
         }
         else if (dltdata.ivalue != -1)
         {
@@ -669,8 +679,10 @@ int main(int argc, char *argv[])
             printf("Timing packets: %d\n", dltdata.ivalue);
 
             /* send control message in*/
-            if (dlt_client_send_timing_pakets(&g_dltclient, dltdata.ivalue) != DLT_RETURN_OK)
+            if (dlt_client_send_timing_pakets(&g_dltclient, (uint8_t) dltdata.ivalue) != DLT_RETURN_OK) {
                 fprintf (stderr, "ERROR: Could not send timing packets\n");
+                ret = -1;
+            }
         }
         else if (dltdata.oflag != -1)
         {
@@ -678,8 +690,10 @@ int main(int argc, char *argv[])
             printf("Store config\n");
 
             /* send control message in*/
-            if (dlt_client_send_store_config(&g_dltclient) != DLT_RETURN_OK)
+            if (dlt_client_send_store_config(&g_dltclient) != DLT_RETURN_OK) {
                 fprintf (stderr, "ERROR: Could not send store config\n");
+                ret = -1;
+            }
         }
         else if (dltdata.gflag != -1)
         {
@@ -687,8 +701,10 @@ int main(int argc, char *argv[])
             printf("Reset to factory default\n");
 
             /* send control message in*/
-            if (dlt_client_send_reset_to_factory_default(&g_dltclient) != DLT_RETURN_OK)
+            if (dlt_client_send_reset_to_factory_default(&g_dltclient) != DLT_RETURN_OK) {
                 fprintf (stderr, "ERROR: Could not send reset to factory default\n");
+                ret = -1;
+            }
         }
         else if (dltdata.jvalue == 1)
         {
@@ -710,6 +726,8 @@ int main(int argc, char *argv[])
         ts.tv_sec = (dltdata.tvalue * NANOSEC_PER_MILLISEC) / NANOSEC_PER_SEC;
         ts.tv_nsec = (dltdata.tvalue * NANOSEC_PER_MILLISEC) % NANOSEC_PER_SEC;
         nanosleep(&ts, NULL);
+    } else {
+        ret = -1;
     }
 
     /* Dlt Client Cleanup */
@@ -722,7 +740,7 @@ int main(int argc, char *argv[])
 
     dlt_filter_free(&(dltdata.filter), dltdata.vflag);
 
-    return 0;
+    return ret;
 }
 
 int dlt_receive_message_callback(DltMessage *message, void *data)
@@ -744,7 +762,7 @@ int dlt_receive_message_callback(DltMessage *message, void *data)
 
     /* get response service id */
     ptr = message->databuffer;
-    datalength = message->datasize;
+    datalength =(int32_t) message->datasize;
 
     DLT_MSG_READ_VALUE(uint32_tmp, ptr, datalength, uint32_t);
     id = DLT_ENDIAN_GET_32(message->standardheader->htyp, uint32_tmp);
