@@ -75,6 +75,8 @@
 #include <string.h>
 #include <glob.h>
 #include <syslog.h>
+#include <signal.h>
+#include <sys/socket.h>
 #ifdef __linux__
 #   include <linux/limits.h>
 #else
@@ -86,6 +88,24 @@
 
 #define DLT_RECEIVE_ECU_ID "RECV"
 
+DltClient dltclient;
+
+void signal_handler(int signal)
+{
+    switch (signal) {
+    case SIGHUP:
+    case SIGTERM:
+    case SIGINT:
+    case SIGQUIT:
+        /* stop main loop */
+        shutdown(dltclient.receiver.fd, SHUT_RD);
+        break;
+    default:
+        /* This case should never happen! */
+        break;
+    } /* switch */
+}
+
 /* Function prototypes */
 int dlt_receive_message_callback(DltMessage *message, void *data);
 
@@ -96,6 +116,7 @@ typedef struct {
     int mflag;
     int vflag;
     int yflag;
+    int uflag;
     char *ovalue;
     char *ovaluebase; /* ovalue without ".dlt" */
     char *fvalue;
@@ -131,6 +152,7 @@ void usage()
     printf("  -v            Verbose mode\n");
     printf("  -h            Usage\n");
     printf("  -y            Serial device mode\n");
+    printf("  -u            UDP multicast mode\n");
     printf("  -b baudrate   Serial device baudrate (Default: 115200)\n");
     printf("  -e ecuid      Set ECU ID (Default: RECV)\n");
     printf("  -o filename   Output messages in new DLT file\n");
@@ -288,7 +310,6 @@ void dlt_receive_close_output_file(DltReceiveData *dltdata)
  */
 int main(int argc, char *argv[])
 {
-    DltClient dltclient;
     DltReceiveData dltdata;
     int c;
     int index;
@@ -300,6 +321,7 @@ int main(int argc, char *argv[])
     dltdata.mflag = 0;
     dltdata.vflag = 0;
     dltdata.yflag = 0;
+    dltdata.uflag = 0;
     dltdata.ovalue = 0;
     dltdata.ovaluebase = 0;
     dltdata.fvalue = 0;
@@ -310,10 +332,19 @@ int main(int argc, char *argv[])
     dltdata.totalbytes = 0;
     dltdata.part_num = -1;
 
+    /* Config signal handler */
+    struct sigaction act;
+    act.sa_handler = signal_handler;
+    sigemptyset(&act.sa_mask);
+    sigaction(SIGHUP, &act, 0);
+    sigaction(SIGTERM, &act, 0);
+    sigaction(SIGINT, &act, 0);
+    sigaction(SIGQUIT, &act, 0);
+
     /* Fetch command line arguments */
     opterr = 0;
 
-    while ((c = getopt (argc, argv, "vashyxmf:o:e:b:c:")) != -1)
+    while ((c = getopt (argc, argv, "vashyuxmf:o:e:b:c:")) != -1)
         switch (c) {
         case 'v':
         {
@@ -350,6 +381,11 @@ int main(int argc, char *argv[])
             dltdata.yflag = 1;
             break;
         }
+        case 'u':
+        {
+            dltdata.uflag = 1;
+            break;
+        }
         case 'f':
         {
             dltdata.fvalue = optarg;
@@ -425,9 +461,14 @@ int main(int argc, char *argv[])
     dlt_client_register_message_callback(dlt_receive_message_callback);
 
     /* Setup DLT Client structure */
-    dltclient.mode = dltdata.yflag;
+    if(dltdata.uflag) {
+        dltclient.mode = DLT_CLIENT_MODE_UDP_MULTICAST;
+    }
+    else {
+        dltclient.mode = dltdata.yflag;
+    }
 
-    if (dltclient.mode == DLT_CLIENT_MODE_TCP) {
+    if (dltclient.mode == DLT_CLIENT_MODE_TCP || dltclient.mode == DLT_CLIENT_MODE_UDP_MULTICAST) {
         for (index = optind; index < argc; index++)
             if (dlt_client_set_server_ip(&dltclient, argv[index]) == -1) {
                 fprintf(stderr, "set server ip didn't succeed\n");
@@ -576,12 +617,12 @@ int dlt_receive_message_callback(DltMessage *message, void *data)
         /* if file output enabled write message */
         if (dltdata->ovalue) {
             iov[0].iov_base = message->headerbuffer;
-            iov[0].iov_len = message->headersize;
+            iov[0].iov_len = (uint32_t) message->headersize;
             iov[1].iov_base = message->databuffer;
-            iov[1].iov_len = message->datasize;
+            iov[1].iov_len = (uint32_t) message->datasize;
 
             if (dltdata->climit > -1) {
-                int bytes_to_write = message->headersize + message->datasize;
+                uint32_t bytes_to_write = message->headersize + message->datasize;
 
                 if ((bytes_to_write + dltdata->totalbytes > dltdata->climit)) {
                     dlt_receive_close_output_file(dltdata);
@@ -596,7 +637,7 @@ int dlt_receive_message_callback(DltMessage *message, void *data)
                 }
             }
 
-            bytes_written = writev(dltdata->ohandle, iov, 2);
+            bytes_written = (int) writev(dltdata->ohandle, iov, 2);
 
             dltdata->totalbytes += bytes_written;
 
