@@ -76,6 +76,8 @@
 /* Stack size of ecu version thread */
 #define DLT_DAEMON_ECU_VERSION_THREAD_STACKSIZE 100000
 
+/* Size of receive buffer for shm connection  (from user application) */
+#define DLT_SHM_RCV_BUFFER_SIZE     10000
 /* Size of receive buffer for fifo connection  (from user application) */
 #define DLT_DAEMON_RCVBUFSIZE       10024
 /* Size of receive buffer for socket connection (from dlt client) */
