@@ -49,13 +49,14 @@ DLT_STATIC DltReturnValue dlt_logstorage_split_ecuid(char *key,
     if ((len > (DLT_ID_SIZE + 2)) || (len < 2))
         return DLT_RETURN_ERROR;
 
-    memcpy(ecuid, key, (len - 2));
+    memcpy(ecuid, key, (size_t) (len - 2));
     memcpy(apid, ".*", 2);
     memcpy(ctid, ".*", 2);
 
     return DLT_RETURN_OK;
 }
 
+unsigned int g_logstorage_cache_max;
 /**
  * dlt_logstorage_split_ctid
  *
@@ -75,7 +76,7 @@ DLT_STATIC DltReturnValue dlt_logstorage_split_ctid(char *key,
     if ((len > (DLT_ID_SIZE + 2)) || (len < 1))
         return DLT_RETURN_ERROR;
 
-    strncpy(ctid, (key + 2), (len - 1));
+    strncpy(ctid, (key + 2), (size_t) (len - 1));
     memcpy(apid, ".*", 2);
 
     return DLT_RETURN_OK;
@@ -100,7 +101,7 @@ DLT_STATIC DltReturnValue dlt_logstorage_split_apid(char *key,
     if ((len > (DLT_ID_SIZE + 2)) || (len < 2))
         return DLT_RETURN_ERROR;
 
-    strncpy(apid, key + 1, (len - 2));
+    strncpy(apid, key + 1, (size_t) (len - 2));
     memcpy(ctid, ".*", 2);
 
     return DLT_RETURN_OK;
@@ -217,7 +218,7 @@ DLT_STATIC DltReturnValue dlt_logstorage_split_multi(char *key,
     if (tok == NULL)
         return DLT_RETURN_ERROR;
 
-    len = strlen(tok);
+    len = (int) strlen(tok);
 
     if (key[len + 1] == ':') {
         strncpy(ecuid, tok, DLT_ID_SIZE);
@@ -263,7 +264,7 @@ DLT_STATIC DltReturnValue dlt_logstorage_split_key(char *key, char *apid,
     if ((key == NULL) || (apid == NULL) || (ctid == NULL) || (ecuid == NULL))
         return DLT_RETURN_WRONG_PARAMETER;
 
-    len = strlen(key);
+    len = (int) strlen(key);
 
     sep = strchr (key, ':');
 
@@ -335,7 +336,7 @@ DLT_STATIC DltReturnValue dlt_daemon_logstorage_update_passive_node_context(
     dlt_set_id(req.apid, apid);
     dlt_set_id(req.ctid, ctid);
 
-    req.log_level = loglevel;
+    req.log_level = (uint8_t) loglevel;
 
     if (dlt_gateway_send_control_message(con, &ctrl, (void *)&req, verbose) != 0) {
         dlt_vlog(LOG_ERR,
@@ -381,7 +382,7 @@ DLT_STATIC DltReturnValue dlt_daemon_logstorage_send_log_level(DltDaemon *daemon
     if (strncmp(ecuid, daemon->ecuid, DLT_ID_SIZE) == 0) {
         old_log_level = context->storage_log_level;
 
-        context->storage_log_level = DLT_OFFLINE_LOGSTORAGE_MAX(loglevel,
+        context->storage_log_level = (int8_t) DLT_OFFLINE_LOGSTORAGE_MAX(loglevel,
                                                                 context->storage_log_level);
 
         if (context->storage_log_level > old_log_level) {
@@ -486,7 +487,7 @@ DLT_STATIC DltReturnValue dlt_daemon_logstorage_force_reset_level(DltDaemon *dae
 {
     int ll = DLT_LOG_DEFAULT;
     int num = 0;
-    int i = 0;
+    uint32_t i = 0;
     DltLogStorageFilterConfig *config[DLT_CONFIG_FILE_SECTIONS_MAX] = { 0 };
 
     if ((daemon == NULL) || (daemon_local == NULL) || (ecuid == NULL) ||
@@ -533,7 +534,7 @@ DLT_STATIC DltReturnValue dlt_daemon_logstorage_force_reset_level(DltDaemon *dae
  * @param daemon_local      DltDaemonLocal structure
  * @param id                application id or context id
  * @param curr_log_level    log level to be set to context
- * @param cmp_flag          compare flag (1 id is apid, 2 id is ctid)
+ * @param cmp_flag          compare flag
  * @param ecuid             ecu id where application runs
  * @param verbose           If set to true verbose information is printed out
  * @return                  0 on success, -1 on error
@@ -551,8 +552,8 @@ DltReturnValue dlt_logstorage_update_all_contexts(DltDaemon *daemon,
     char tmp_id[DLT_ID_SIZE + 1] = { '\0' };
 
     if ((daemon == NULL) || (daemon_local == NULL) || (id == NULL) ||
-        (ecuid == NULL) || (cmp_flag < DLT_DAEMON_LOGSTORAGE_CMP_APID) ||
-        (cmp_flag > DLT_DAEMON_LOGSTORAGE_CMP_CTID)) {
+        (ecuid == NULL) || (cmp_flag <= DLT_DAEMON_LOGSTORAGE_CMP_MIN) ||
+        (cmp_flag >= DLT_DAEMON_LOGSTORAGE_CMP_MAX)) {
         dlt_vlog(LOG_ERR, "Wrong parameter in function %s\n", __func__);
         return DLT_RETURN_WRONG_PARAMETER;
     }
@@ -563,10 +564,13 @@ DltReturnValue dlt_logstorage_update_all_contexts(DltDaemon *daemon,
         return DLT_RETURN_ERROR;
 
     for (i = 0; i < user_list->num_contexts; i++) {
-        if (cmp_flag == 1)
+        if (cmp_flag == DLT_DAEMON_LOGSTORAGE_CMP_APID)
             dlt_set_id(tmp_id, user_list->contexts[i].apid);
-        else
+        else if (cmp_flag == DLT_DAEMON_LOGSTORAGE_CMP_CTID)
             dlt_set_id(tmp_id, user_list->contexts[i].ctid);
+        else
+            /* this is for the case when both apid and ctid are wildcard */
+            dlt_set_id(tmp_id, ".*");
 
         if (strncmp(id, tmp_id, DLT_ID_SIZE) == 0) {
             if (curr_log_level > 0)
@@ -704,8 +708,20 @@ DltReturnValue dlt_logstorage_update_context_loglevel(DltDaemon *daemon,
     if (ecuid[0] == '\0') /* ECU id was not specified in filter configuration */
         dlt_set_id(ecuid, daemon->ecuid);
 
-    /* wildcard for context id, find all contexts of given application id */
-    if (strcmp(ctid, ".*") == 0) {
+    /* check wildcard for both apid and ctid first of all */
+    if (strcmp(ctid, ".*") == 0 && strcmp(apid, ".*") == 0) {
+        cmp_flag = DLT_DAEMON_LOGSTORAGE_CMP_ECID;
+
+        if (dlt_logstorage_update_all_contexts(daemon,
+                                               daemon_local,
+                                               apid,
+                                               curr_log_level,
+                                               cmp_flag,
+                                               ecuid,
+                                               verbose) != 0)
+            return DLT_RETURN_ERROR;
+    }
+    else if (strcmp(ctid, ".*") == 0) {
         cmp_flag = DLT_DAEMON_LOGSTORAGE_CMP_APID;
 
         if (dlt_logstorage_update_all_contexts(daemon,
@@ -772,7 +788,6 @@ void dlt_daemon_logstorage_reset_application_loglevel(DltDaemon *daemon,
     DltLogStorageFilterList **tmp = NULL;
     int i = 0;
     char key[DLT_OFFLINE_LOGSTORAGE_MAX_KEY_LEN + 1] = { '\0' };
-    int num_device_configured = 0;
     unsigned int status;
     int log_level = 0;
 
@@ -792,14 +807,6 @@ void dlt_daemon_logstorage_reset_application_loglevel(DltDaemon *daemon,
         (handle->config_status != DLT_OFFLINE_LOGSTORAGE_CONFIG_DONE))
         return;
 
-    /* First, check number of devices configured */
-    for (i = 0; i < max_device; i++) {
-        status = daemon->storage_handle[i].config_status;
-
-        if (status == DLT_OFFLINE_LOGSTORAGE_CONFIG_DONE)
-            num_device_configured++;
-    }
-
     /* for all filters (keys) check if application context are already running
      * and log level need to be reset*/
     tmp = &(handle->config_list);
@@ -813,19 +820,10 @@ void dlt_daemon_logstorage_reset_application_loglevel(DltDaemon *daemon,
                           + (i * DLT_OFFLINE_LOGSTORAGE_MAX_KEY_LEN)),
                     DLT_OFFLINE_LOGSTORAGE_MAX_KEY_LEN);
 
-            if (num_device_configured == 1)
-            {
-                /* Reset context log level and send to application */
-                log_level = DLT_DAEMON_LOGSTORAGE_RESET_SEND_LOGLEVEL;
-            }
-            else
-            {
-                /**
-                 * Reset context log level do not send to application as other
-                 * devices can have same configuration
-                 * */
-                log_level = DLT_DAEMON_LOGSTORAGE_RESET_LOGLEVEL;
-            }
+            /* dlt-daemon wants to reset loglevel if
+             * a logstorage device is disconnected.
+             */
+            log_level = DLT_DAEMON_LOGSTORAGE_RESET_LOGLEVEL;
 
             dlt_logstorage_update_context_loglevel(
                     daemon,
@@ -977,11 +975,11 @@ int dlt_daemon_logstorage_get_loglevel(DltDaemon *daemon,
                 /* If logstorage configuration do not contain file name,
                  * then it is non verbose control filter, so return level as in this filter */
                 if (config[j]->file_name == NULL) {
-                    storage_loglevel = config[j]->log_level;
+                    storage_loglevel = (int8_t) config[j]->log_level;
                     break;
                 }
 
-                configured_loglevel = config[j]->log_level;
+                configured_loglevel = (int8_t) config[j]->log_level;
                 storage_loglevel = DLT_OFFLINE_LOGSTORAGE_MAX(
                     configured_loglevel,
                     storage_loglevel);
@@ -1016,7 +1014,7 @@ void dlt_daemon_logstorage_write(DltDaemon *daemon,
                                  unsigned char *data3,
                                  int size3)
 {
-    int i = 0;
+    uint32_t i = 0;
     DltLogStorageUserConfig file_config;
 
     if ((daemon == NULL) || (user_config == NULL) ||
@@ -1097,6 +1095,16 @@ int dlt_daemon_logstorage_setup_internal_storage(DltDaemon *daemon,
                                                       0,
                                                       verbose);
 
+    if (daemon->storage_handle[0].maintain_logstorage_loglevel !=
+            DLT_MAINTAIN_LOGSTORAGE_LOGLEVEL_UNDEF) {
+        daemon->maintain_logstorage_loglevel =
+                daemon->storage_handle[0].maintain_logstorage_loglevel;
+
+        dlt_vlog(LOG_DEBUG, "[%s] Startup with maintain loglevel: [%d]\n",
+                        __func__,
+                        daemon->storage_handle[0].maintain_logstorage_loglevel);
+    }
+
     return ret;
 }
 
@@ -1110,7 +1118,7 @@ int dlt_daemon_logstorage_cleanup(DltDaemon *daemon,
                                   DltDaemonLocal *daemon_local,
                                   int verbose)
 {
-    int i = 0;
+    uint32_t i = 0;
 
     PRINT_FUNCTION_VERBOSE(verbose);
 
@@ -1144,7 +1152,7 @@ int dlt_daemon_logstorage_sync_cache(DltDaemon *daemon,
                                      char *mnt_point,
                                      int verbose)
 {
-    int i = 0;
+    uint32_t i = 0;
     DltLogStorage *handle = NULL;
 
     PRINT_FUNCTION_VERBOSE(verbose);
@@ -1202,7 +1210,7 @@ DltLogStorage *dlt_daemon_logstorage_get_device(DltDaemon *daemon,
                                                 char *mnt_point,
                                                 int verbose)
 {
-    int i = 0;
+    uint32_t i = 0;
     int len = 0;
     int len1 = 0;
     int len2 = 0;
@@ -1212,17 +1220,17 @@ DltLogStorage *dlt_daemon_logstorage_get_device(DltDaemon *daemon,
     if ((daemon == NULL) || (daemon_local == NULL) || (mnt_point == NULL))
         return NULL;
 
-    len1 = strlen(mnt_point);
+    len1 = (int) strlen(mnt_point);
 
     for (i = 0; i < daemon_local->flags.offlineLogstorageMaxDevices; i++) {
-        len2 = strlen(daemon->storage_handle[i].device_mount_point);
+        len2 = (int) strlen(daemon->storage_handle[i].device_mount_point);
 
         /* Check if the requested device path is already used as log storage
          * device. Check for strlen first, to avoid comparison errors when
          * final '/' is given or not */
         len = len1 > len2 ? len2 : len1;
 
-        if (strncmp(daemon->storage_handle[i].device_mount_point, mnt_point, len) == 0)
+        if (strncmp(daemon->storage_handle[i].device_mount_point, mnt_point, (size_t) len) == 0)
             return &daemon->storage_handle[i];
     }
 
