@@ -32,6 +32,7 @@
 #include "dlt_offline_logstorage_behavior.h"
 #include "dlt_offline_logstorage_behavior_internal.h"
 
+unsigned int g_logstorage_cache_size;
 /**
  * dlt_logstorage_log_file_name
  *
@@ -72,7 +73,7 @@ void dlt_logstorage_log_file_name(char *log_file_name,
         unsigned int digit_idx = 0;
         unsigned int i = 0;
         snprintf(file_index, 10, "%d", idx);
-        digit_idx = strlen(file_index);
+        digit_idx = (unsigned int) strlen(file_index);
 
         if (file_config->logfile_counteridxlen > digit_idx)
         {
@@ -88,9 +89,10 @@ void dlt_logstorage_log_file_name(char *log_file_name,
         char stamp[DLT_OFFLINE_LOGSTORAGE_TIMESTAMP_LEN + 1] = { 0 };
         time_t t = time(NULL);
         struct tm tm_info;
+        ssize_t n = 0;
         tzset();
         localtime_r(&t, &tm_info);
-        if (snprintf(stamp,
+        n = snprintf(stamp,
                      DLT_OFFLINE_LOGSTORAGE_TIMESTAMP_LEN + 1,
                      "%c%04d%02d%02d-%02d%02d%02d",
                      file_config->logfile_delimiter,
@@ -99,7 +101,8 @@ void dlt_logstorage_log_file_name(char *log_file_name,
                      tm_info.tm_mday,
                      tm_info.tm_hour,
                      tm_info.tm_min,
-                     tm_info.tm_sec) != 0) {
+                     tm_info.tm_sec);
+        if (n < 0 || (size_t)n > (DLT_OFFLINE_LOGSTORAGE_TIMESTAMP_LEN + 1)) {
             dlt_vlog(LOG_WARNING, "%s: snprintf truncation %s\n", __func__,
                      stamp);
         }
@@ -115,14 +118,15 @@ void dlt_logstorage_log_file_name(char *log_file_name,
  * Sort the filenames with index based ascending order (bubble sort)
  *
  * @param head              Log filename list
- * @ return                 None
+ * @ return                 The last (biggest) index
  */
-void dlt_logstorage_sort_file_name(DltLogStorageFileList **head)
+unsigned int dlt_logstorage_sort_file_name(DltLogStorageFileList **head)
 {
     int done = 0;
+    unsigned int max_idx = 0;
 
     if ((head == NULL) || (*head == NULL) || ((*head)->next == NULL))
-        return;
+        return 0;
 
     while (!done) {
         /* "source" of the pointer to the current node in the list struct */
@@ -133,7 +137,9 @@ void dlt_logstorage_sort_file_name(DltLogStorageFileList **head)
         done = 1;
 
         while (nx) {
+            max_idx = nx->idx;
             if (nd->idx > nx->idx) {
+                max_idx = nd->idx;
                 nd->next = nx->next;
                 nx->next = nd;
                 *pv = nx;
@@ -146,6 +152,8 @@ void dlt_logstorage_sort_file_name(DltLogStorageFileList **head)
             nx = nx->next;
         }
     }
+
+    return max_idx;
 }
 
 /**
@@ -167,8 +175,17 @@ void dlt_logstorage_rearrange_file_name(DltLogStorageFileList **head)
     if ((head == NULL) || (*head == NULL) || ((*head)->next == NULL))
         return;
 
+    if ((*head)->idx != 1)
+    {
+        /* Do not sort */
+        return;
+    }
+
     for (n = *head; n != NULL; n = n->next) {
-        if (n && n_prev) {
+        /* Compare the diff between n->idx and n_prev->idx only if
+         * wrap_post and wrap_pre are not set yet. Otherwise continue the loop
+         * until the tail */
+        if (n && n_prev && !wrap_post && !wrap_pre) {
             if ((n->idx - n_prev->idx) != 1) {
                 wrap_post = n;
                 wrap_pre = n_prev;
@@ -216,16 +233,16 @@ unsigned int dlt_logstorage_get_idx_of_log_file(DltLogStorageUserConfig *file_co
         return -1;
     }
 
-    filename_len = strlen(file) - strlen(filename);
+    filename_len = (unsigned int) (strlen(file) - strlen(filename));
 
     /* index is retrived from file name */
     if (file_config->logfile_timestamp) {
-        fileindex_len = strlen(file) -
+        fileindex_len = (unsigned int) strlen(file) -
             (DLT_OFFLINE_LOGSTORAGE_FILE_EXTENSION_LEN +
              DLT_OFFLINE_LOGSTORAGE_TIMESTAMP_LEN +
              filename_len + 1);
 
-        idx = (int)strtol(&file[strlen(file) -
+        idx = (unsigned int) strtol(&file[strlen(file) -
                                 (DLT_OFFLINE_LOGSTORAGE_FILE_EXTENSION_LEN +
                                  fileindex_len +
                                  DLT_OFFLINE_LOGSTORAGE_TIMESTAMP_LEN)],
@@ -233,11 +250,11 @@ unsigned int dlt_logstorage_get_idx_of_log_file(DltLogStorageUserConfig *file_co
                           10);
     }
     else {
-        fileindex_len = strlen(file) -
+        fileindex_len = (unsigned int) strlen(file) -
             (DLT_OFFLINE_LOGSTORAGE_FILE_EXTENSION_LEN +
              filename_len + 1);
 
-        idx = (int)strtol(&file[strlen(file) -
+        idx = (unsigned int) strtol(&file[strlen(file) -
                                 (DLT_OFFLINE_LOGSTORAGE_FILE_EXTENSION_LEN
                                  + fileindex_len)], &endptr, 10);
     }
@@ -264,9 +281,11 @@ int dlt_logstorage_storage_dir_info(DltLogStorageUserConfig *file_config,
                                     char *path,
                                     DltLogStorageFilterConfig *config)
 {
+    int check = 0;
     int i = 0;
     int cnt = 0;
     int ret = 0;
+    unsigned int max_idx = 0;
     struct dirent **files = { 0 };
     unsigned int current_idx = 0;
     DltLogStorageFileList *n = NULL;
@@ -281,11 +300,12 @@ int dlt_logstorage_storage_dir_info(DltLogStorageUserConfig *file_config,
     cnt = scandir(path, &files, 0, alphasort);
 
     if (cnt < 0) {
-        dlt_log(LOG_ERR,
-                "dlt_logstorage_storage_dir_info: Failed to scan directory\n");
+        dlt_vlog(LOG_ERR, "%s: Failed to scan directory\n", __func__);
         return -1;
     }
 
+    dlt_vlog(LOG_DEBUG, "%s: Scanned [%d] files from %s\n", __func__, cnt, path);
+
     /* In order to have a latest status of file list,
      * the existing records must be deleted before updating
      */
@@ -303,7 +323,7 @@ int dlt_logstorage_storage_dir_info(DltLogStorageUserConfig *file_config,
     }
 
     for (i = 0; i < cnt; i++) {
-        int len = 0;
+        size_t len = 0;
         len = strlen(config->file_name);
 
         if ((strncmp(files[i]->d_name, config->file_name, len) == 0) &&
@@ -341,12 +361,25 @@ int dlt_logstorage_storage_dir_info(DltLogStorageUserConfig *file_config,
             (*tmp)->name = strdup(files[i]->d_name);
             (*tmp)->idx = current_idx;
             (*tmp)->next = NULL;
+            check++;
         }
     }
 
+    dlt_vlog(LOG_DEBUG, "%s: After dir scan: [%d] files of [%s]\n", __func__,
+             check, config->file_name);
+
     if (ret == 0) {
-        dlt_logstorage_sort_file_name(&config->records);
-        dlt_logstorage_rearrange_file_name(&config->records);
+        max_idx = dlt_logstorage_sort_file_name(&config->records);
+
+        /* Fault tolerance:
+         * In case there are some log files are removed but
+         * the index is still not reaching maxcounter, no need
+         * to perform rearrangement of filename.
+         * This would help the log keeps growing until maxcounter is reached and
+         * the maximum number of log files could be obtained.
+         */
+        if (max_idx == file_config->logfile_maxcounter)
+            dlt_logstorage_rearrange_file_name(&config->records);
     }
 
     /* free scandir result */
@@ -442,23 +475,32 @@ int dlt_logstorage_open_log_file(DltLogStorageFilterConfig *config,
         (*tmp)->next = NULL;
     }
     else {
-        /* newest file available*/
         strcat(absolute_file_path, storage_path);
-        strcat(absolute_file_path, (*newest)->name);
 
-        if (config->working_file_name != NULL) {
-            free(config->working_file_name);
-            config->working_file_name = NULL;
+        /* newest file available
+         * Since the working file is already updated from newest file info
+         * So if there is already wrap-up, the newest file will be the working file
+         */
+        if ((config->wrap_id == 0) || (config->working_file_name == NULL)) {
+            if (config->working_file_name != NULL) {
+                free(config->working_file_name);
+                config->working_file_name = NULL;
+            }
+            config->working_file_name = strdup((*newest)->name);
         }
+        strcat(absolute_file_path, config->working_file_name);
 
-        config->working_file_name = strdup((*newest)->name);
+        dlt_vlog(LOG_DEBUG,
+                 "%s: Number of log files-newest file-wrap_id [%d]-[%s]-[%d]\n",
+                 __func__, num_log_files, config->working_file_name,
+                 config->wrap_id);
 
         ret = stat(absolute_file_path, &s);
 
         /* if size is enough, open it */
-        if ((ret == 0) && (s.st_size + msg_size < (int)config->file_size)) {
+        if ((ret == 0) && (s.st_size + msg_size <= (int) config->file_size)) {
             config->log = fopen(absolute_file_path, "a+");
-            config->current_write_file_offset = s.st_size;
+            config->current_write_file_offset = (unsigned int) s.st_size;
         }
         else {
             /* no space in file or file stats cannot be read */
@@ -466,18 +508,20 @@ int dlt_logstorage_open_log_file(DltLogStorageFilterConfig *config,
 
             /* get index of newest log file */
             idx = dlt_logstorage_get_idx_of_log_file(file_config,
-                                                     (*newest)->name);
+                                                     config->working_file_name);
             idx += 1;
 
             /* wrap around if max index is reached or an error occurred
              * while calculating index from file name */
-            if ((idx > file_config->logfile_maxcounter) || (idx == 0))
+            if ((idx > file_config->logfile_maxcounter) || (idx == 0)) {
                 idx = 1;
+                config->wrap_id += 1;
+            }
 
             dlt_logstorage_log_file_name(file_name,
                                          file_config,
                                          config->file_name,
-                                         idx);
+                                         (int) idx);
 
             /* concatenate path and file and open absolute path */
             memset(absolute_file_path,
@@ -491,8 +535,23 @@ int dlt_logstorage_open_log_file(DltLogStorageFilterConfig *config,
                 config->working_file_name = strdup(file_name);
             }
 
+            /* If there is already wrap-up, check the existence of file
+             * remove it and reopen it.
+             * In this case number of log file won't be increased*/
+            if (config->wrap_id && stat(absolute_file_path, &s) == 0) {
+                remove(absolute_file_path);
+                num_log_files -= 1;
+                dlt_vlog(LOG_DEBUG,
+                         "%s: Remove '%s' (num_log_files: %d, config->num_files:%d)\n",
+                         __func__, absolute_file_path, num_log_files, config->num_files);
+            }
+
             config->log = fopen(absolute_file_path, "a+");
 
+            dlt_vlog(LOG_DEBUG,
+                     "%s: Filename and Index after updating [%s]-[%d]\n",
+                     __func__, file_name, idx);
+
             /* Add file to file list */
             *tmp = malloc(sizeof(DltLogStorageFileList));
 
@@ -517,8 +576,13 @@ int dlt_logstorage_open_log_file(DltLogStorageFilterConfig *config,
                        sizeof(absolute_file_path) / sizeof(char));
                 strcat(absolute_file_path, storage_path);
                 strcat(absolute_file_path, (*head)->name);
+                dlt_vlog(LOG_DEBUG,
+                         "%s: Remove '%s' (num_log_files: %d, config->num_files:%d)\n",
+                         __func__, absolute_file_path, num_log_files,
+                         config->num_files);
                 remove(absolute_file_path);
                 free((*head)->name);
+                (*head)->name = NULL;
                 *head = n->next;
                 n->next = NULL;
                 free(n);
@@ -527,8 +591,21 @@ int dlt_logstorage_open_log_file(DltLogStorageFilterConfig *config,
     }
 
     if (config->log == NULL) {
-        dlt_log(LOG_ERR,
-                "dlt_logstorage_create_log_file: Unable to open log file.\n");
+        if (*tmp != NULL) {
+            if ((*tmp)->name != NULL) {
+                free((*tmp)->name);
+                (*tmp)->name = NULL;
+            }
+            free(*tmp);
+            *tmp = NULL;
+        }
+
+        if (config->working_file_name != NULL) {
+            free(config->working_file_name);
+            config->working_file_name = NULL;
+        }
+
+        dlt_vlog(LOG_ERR, "%s: Unable to open log file.\n", __func__);
         return -1;
     }
 
@@ -642,8 +719,8 @@ DLT_STATIC int dlt_logstorage_sync_to_file(DltLogStorageFilterConfig *config,
     int ret = 0;
     int start_index = 0;
     int end_index = 0;
-    int count = 0;
-    int remain_file_size = 0;
+    unsigned int count = 0;
+    unsigned int remain_file_size = 0;
 
     if ((config == NULL) || (file_config == NULL) || (dev_path == NULL) ||
         (footer == NULL))
@@ -664,7 +741,7 @@ DLT_STATIC int dlt_logstorage_sync_to_file(DltLogStorageFilterConfig *config,
     }
 
     if (dlt_logstorage_open_log_file(config, file_config,
-            dev_path, count, true) != 0) {
+            dev_path, (int) count, true) != 0) {
         dlt_vlog(LOG_ERR, "%s: failed to open log file\n", __func__);
         return -1;
     }
@@ -677,14 +754,14 @@ DLT_STATIC int dlt_logstorage_sync_to_file(DltLogStorageFilterConfig *config,
         start_index = dlt_logstorage_find_dlt_header(config->cache, start_offset,
                                                      remain_file_size);
         end_index = dlt_logstorage_find_last_dlt_header(config->cache,
-                                                     start_offset + start_index,
-                                                     remain_file_size - start_index);
-        count = end_index - start_index;
+                                                     start_offset + (unsigned int) start_index,
+                                                     remain_file_size - (unsigned int) start_index);
+        count = (unsigned int) (end_index - start_index);
 
         if ((start_index >= 0) && (end_index > start_index) &&
             (count > 0) && (count <= remain_file_size))
         {
-            ret = fwrite((uint8_t*)config->cache + start_offset + start_index,
+            ret = (int) fwrite((uint8_t*)config->cache + start_offset + start_index,
                         count, 1, config->log);
             dlt_logstorage_check_write_ret(config, ret);
 
@@ -706,7 +783,7 @@ DLT_STATIC int dlt_logstorage_sync_to_file(DltLogStorageFilterConfig *config,
     }
 
     start_index = dlt_logstorage_find_dlt_header(config->cache, start_offset, count);
-    count = end_offset - start_offset - start_index;
+    count = end_offset - start_offset - (unsigned int) start_index;
 
     if ((start_index >= 0) && (count > 0))
     {
@@ -714,14 +791,14 @@ DLT_STATIC int dlt_logstorage_sync_to_file(DltLogStorageFilterConfig *config,
         if (config->log == NULL)
         {
             if (dlt_logstorage_prepare_on_msg(config, file_config, dev_path,
-                                              count, NULL) != 0)
+                                              (int) count, NULL) != 0)
             {
                 dlt_vlog(LOG_ERR, "%s: failed to prepare log file\n", __func__);
                 return -1;
             }
         }
 
-        ret = fwrite((uint8_t*)config->cache + start_offset + start_index, count, 1,
+        ret = (int) fwrite((uint8_t*)config->cache + start_offset + start_index, count, 1,
                      config->log);
         dlt_logstorage_check_write_ret(config, ret);
 
@@ -744,25 +821,37 @@ DLT_STATIC int dlt_logstorage_sync_to_file(DltLogStorageFilterConfig *config,
  * @param file_config   User configurations for log file
  * @param dev_path      Storage device path
  * @param log_msg_size  Size of log message
- * @param newest_file   Name of newest file for corresponding filename
+ * @param newest_file_info   Info of newest file for corresponding filename
  * @return 0 on success, -1 on error
  */
 int dlt_logstorage_prepare_on_msg(DltLogStorageFilterConfig *config,
                                   DltLogStorageUserConfig *file_config,
                                   char *dev_path,
                                   int log_msg_size,
-                                  char *newest_file)
+                                  DltNewestFileName *newest_file_info)
 {
     int ret = 0;
     struct stat s;
 
-    if ((config == NULL) || (file_config == NULL) || (dev_path == NULL)) {
+    if ((config == NULL) || (file_config == NULL) || (dev_path == NULL) ||
+        (newest_file_info == NULL)) {
         dlt_vlog(LOG_INFO, "Wrong paratemters\n");
         return -1;
     }
 
     /* This is for ON_MSG/UNSET strategy */
-    if (config->log == NULL) { /* open a new log file */
+    if (config->log == NULL) {
+        /* Sync the wrap id and working file name before opening log file */
+        if (config->wrap_id < newest_file_info->wrap_id) {
+            config->wrap_id = newest_file_info->wrap_id;
+            if (config->working_file_name) {
+                free(config->working_file_name);
+                config->working_file_name = NULL;
+            }
+            config->working_file_name = strdup(newest_file_info->newest_file);
+        }
+
+        /* open a new log file */
         ret = dlt_logstorage_open_log_file(config,
                                            file_config,
                                            dev_path,
@@ -774,10 +863,24 @@ int dlt_logstorage_prepare_on_msg(DltLogStorageFilterConfig *config,
 
         if (ret == 0) {
             /* check if adding new data do not exceed max file size */
+            /* Check if wrap id needs to be updated*/
             if ((s.st_size + log_msg_size > (int)config->file_size) ||
-                strcmp(config->working_file_name, newest_file) != 0) {
+                (strcmp(config->working_file_name, newest_file_info->newest_file) != 0) ||
+                (config->wrap_id < newest_file_info->wrap_id)) {
+
                 fclose(config->log);
                 config->log = NULL;
+
+                /* Sync the wrap id and working file name before opening log file */
+                if (config->wrap_id <= newest_file_info->wrap_id) {
+                    config->wrap_id = newest_file_info->wrap_id;
+                    if (config->working_file_name) {
+                        free(config->working_file_name);
+                        config->working_file_name = NULL;
+                    }
+                    config->working_file_name = strdup(newest_file_info->newest_file);
+                }
+
                 ret = dlt_logstorage_open_log_file(config,
                                                    file_config,
                                                    dev_path,
@@ -832,17 +935,17 @@ int dlt_logstorage_write_on_msg(DltLogStorageFilterConfig *config,
         return -1;
     }
 
-    ret = fwrite(data1, 1, size1, config->log);
+    ret = (int) fwrite(data1, 1, (size_t) size1, config->log);
 
     if (ret != size1)
         dlt_log(LOG_WARNING, "Wrote less data than specified\n");
 
-    ret = fwrite(data2, 1, size2, config->log);
+    ret = (int) fwrite(data2, 1, (size_t) size2, config->log);
 
     if (ret != size2)
         dlt_log(LOG_WARNING, "Wrote less data than specified\n");
 
-    ret = fwrite(data3, 1, size3, config->log);
+    ret = (int) fwrite(data3, 1, (size_t) size3, config->log);
 
     if (ret != size3)
         dlt_log(LOG_WARNING, "Wrote less data than specified\n");
@@ -895,19 +998,38 @@ int dlt_logstorage_sync_on_msg(DltLogStorageFilterConfig *config,
  * @param file_config   User configurations for log file
  * @param dev_path      Storage device path
  * @param log_msg_size  Size of log message
- * @param newest_file   Name of newest file for corresponding filename
+ * @param newest_file_info   Info of newest files for corresponding filename
  * @return 0 on success, -1 on error
  */
 int dlt_logstorage_prepare_msg_cache(DltLogStorageFilterConfig *config,
                                      DltLogStorageUserConfig *file_config,
                                      char *dev_path,
                                      int log_msg_size,
-                                     char *newest_file )
+                                     DltNewestFileName *newest_file_info )
 {
-    (void) newest_file;
-    if ((config == NULL) || (file_config == NULL) || (dev_path == NULL))
+    if ((config == NULL) || (file_config == NULL) ||
+            (dev_path == NULL) || (newest_file_info == NULL))
         return -1;
 
+    /* check if newest file info is available
+     * + working file name is NULL => update directly to newest file
+     * + working file name is not NULL: check if
+     * ++ wrap_ids are different from each other or
+     * ++ newest file name <> working file name
+     */
+    if (newest_file_info->newest_file) {
+        if (config->working_file_name &&
+                ((config->wrap_id != newest_file_info->wrap_id) ||
+                (strcmp(newest_file_info->newest_file, config->working_file_name) != 0))) {
+            free(config->working_file_name);
+            config->working_file_name = NULL;
+        }
+        if (config->working_file_name == NULL) {
+            config->working_file_name = strdup(newest_file_info->newest_file);
+            config->wrap_id = newest_file_info->wrap_id;
+        }
+    }
+
     /* Combinations allowed: on Daemon_Exit with on Demand,File_Size with Daemon_Exit
      *  File_Size with on Demand, Specific_Size with Daemon_Exit,Specific_Size with on Demand
      * Combination not allowed : File_Size with Specific_Size
@@ -967,7 +1089,7 @@ int dlt_logstorage_prepare_msg_cache(DltLogStorageFilterConfig *config,
         else
         {
             /* update current used cache size */
-            g_logstorage_cache_size = cache_size + sizeof(DltLogStorageCacheFooter);
+            g_logstorage_cache_size = (unsigned int) (cache_size + sizeof(DltLogStorageCacheFooter));
         }
     }
 
@@ -1001,8 +1123,8 @@ int dlt_logstorage_write_msg_cache(DltLogStorageFilterConfig *config,
                                    int size3)
 {
     DltLogStorageCacheFooter *footer = NULL;
-    int msg_size;
-    int remain_cache_size;
+    unsigned int msg_size;
+    unsigned int remain_cache_size;
     uint8_t *curr_write_addr = NULL;
     int ret = 0;
     unsigned int cache_size;
@@ -1030,23 +1152,23 @@ int dlt_logstorage_write_msg_cache(DltLogStorageFilterConfig *config,
         dlt_log(LOG_ERR, "Cannot retrieve cache footer. Address is NULL\n");
         return -1;
     }
-    msg_size = size1 + size2 + size3;
+    msg_size = (unsigned int) (size1 + size2 + size3);
     remain_cache_size = cache_size - footer->offset;
 
     if (msg_size <= remain_cache_size) /* add at current position */
     {
         curr_write_addr = (uint8_t*)config->cache + footer->offset;
-        footer->offset += msg_size;
+        footer->offset += (unsigned int) msg_size;
         if (footer->wrap_around_cnt < 1) {
             footer->end_sync_offset = footer->offset;
         }
 
         /* write data to cache */
-        memcpy(curr_write_addr, data1, size1);
+        memcpy(curr_write_addr, data1, (size_t) size1);
         curr_write_addr += size1;
-        memcpy(curr_write_addr, data2, size2);
+        memcpy(curr_write_addr, data2, (size_t) size2);
         curr_write_addr += size2;
-        memcpy(curr_write_addr, data3, size3);
+        memcpy(curr_write_addr, data3, (size_t) size3);
     }
 
     /*
@@ -1104,14 +1226,14 @@ int dlt_logstorage_write_msg_cache(DltLogStorageFilterConfig *config,
             /* start writing from beginning */
             footer->end_sync_offset = footer->offset;
             curr_write_addr = config->cache;
-            footer->offset = msg_size;
+            footer->offset = (unsigned int) msg_size;
 
             /* write data to cache */
-            memcpy(curr_write_addr, data1, size1);
+            memcpy(curr_write_addr, data1, (size_t) size1);
             curr_write_addr += size1;
-            memcpy(curr_write_addr, data2, size2);
+            memcpy(curr_write_addr, data2, (size_t) size2);
             curr_write_addr += size2;
-            memcpy(curr_write_addr, data3, size3);
+            memcpy(curr_write_addr, data3, (size_t) size3);
          }
     }
 
