@@ -62,7 +62,7 @@
 #define DLT_CONFIG_FILE_PATH_MAX_LEN       100 /* absolute path including filename */
 #define DLT_CONFIG_FILE_ENTRY_MAX_LEN      100 /* Entry for section, key and value */
 #define DLT_CONFIG_FILE_LINE_MAX_LEN       210
-#define DLT_CONFIG_FILE_SECTIONS_MAX       100
+#define DLT_CONFIG_FILE_SECTIONS_MAX       125
 #define DLT_CONFIG_FILE_KEYS_MAX            25 /* Maximal keys per section */
 
 typedef struct DltConfigKeyData
@@ -148,4 +148,16 @@ int dlt_config_file_get_value(const DltConfigFile *file,
                               const char *section,
                               const char *key,
                               char *value);
+
+/**
+ * dlt_config_file_check_section_name_exists
+ *
+ * Get name of section number.
+ *
+ * @param[in]  file      DltConfigFile
+ * @param[in]  name      Section name
+ * @return     0 on success/exist, else -1
+ */
+int dlt_config_file_check_section_name_exists(const DltConfigFile *file,
+                                             const char *name);
 #endif
