@@ -80,7 +80,7 @@ typedef struct
 {
     char pattern[DLT_ID_SIZE];      /**< This pattern should be DUH0x01 */
     uint32_t message;               /**< messsage info */
-} PACKED DltUserHeader;
+} DLT_PACKED DltUserHeader;
 
 /**
  * This is the internal message content to exchange control msg register app information between application and daemon.
@@ -90,7 +90,7 @@ typedef struct
     char apid[DLT_ID_SIZE];          /**< application id */
     pid_t pid;                       /**< process id of user application */
     uint32_t description_length;     /**< length of description */
-} PACKED DltUserControlMsgRegisterApplication;
+} DLT_PACKED DltUserControlMsgRegisterApplication;
 
 /**
  * This is the internal message content to exchange control msg unregister app information between application and daemon.
@@ -99,7 +99,7 @@ typedef struct
 {
     char apid[DLT_ID_SIZE];         /**< application id */
     pid_t pid;                      /**< process id of user application */
-} PACKED DltUserControlMsgUnregisterApplication;
+} DLT_PACKED DltUserControlMsgUnregisterApplication;
 
 /**
  * This is the internal message content to exchange control msg register information between application and daemon.
@@ -113,7 +113,7 @@ typedef struct
     int8_t trace_status;             /**< trace status */
     pid_t pid;                       /**< process id of user application */
     uint32_t description_length;     /**< length of description */
-} PACKED DltUserControlMsgRegisterContext;
+} DLT_PACKED DltUserControlMsgRegisterContext;
 
 /**
  * This is the internal message content to exchange control msg unregister information between application and daemon.
@@ -123,7 +123,7 @@ typedef struct
     char apid[DLT_ID_SIZE];         /**< application id */
     char ctid[DLT_ID_SIZE];         /**< context id */
     pid_t pid;                      /**< process id of user application */
-} PACKED DltUserControlMsgUnregisterContext;
+} DLT_PACKED DltUserControlMsgUnregisterContext;
 
 /**
  * This is the internal message content to exchange control msg log level information between application and daemon.
@@ -133,7 +133,7 @@ typedef struct
     uint8_t log_level;             /**< log level */
     uint8_t trace_status;          /**< trace status */
     int32_t log_level_pos;          /**< offset in management structure on user-application side */
-} PACKED DltUserControlMsgLogLevel;
+} DLT_PACKED DltUserControlMsgLogLevel;
 
 /**
  * This is the internal message content to exchange control msg injection information between application and daemon.
@@ -143,7 +143,7 @@ typedef struct
     int32_t log_level_pos;          /**< offset in management structure on user-application side */
     uint32_t service_id;            /**< service id of injection */
     uint32_t data_length_inject;    /**< length of injection message data field */
-} PACKED DltUserControlMsgInjection;
+} DLT_PACKED DltUserControlMsgInjection;
 
 /**
  * This is the internal message content to exchange information about application log level and trace stats between
@@ -154,7 +154,7 @@ typedef struct
     char apid[DLT_ID_SIZE];        /**< application id */
     uint8_t log_level;             /**< log level */
     uint8_t trace_status;          /**< trace status */
-} PACKED DltUserControlMsgAppLogLevelTraceStatus;
+} DLT_PACKED DltUserControlMsgAppLogLevelTraceStatus;
 
 /**
  * This is the internal message content to set the logging mode: off, external, internal, both.
@@ -162,7 +162,7 @@ typedef struct
 typedef struct
 {
     int8_t log_mode;          /**< the mode to be used for logging: off, external, internal, both */
-} PACKED DltUserControlMsgLogMode;
+} DLT_PACKED DltUserControlMsgLogMode;
 
 /**
  * This is the internal message content to get the logging state: 0 = off, 1 = external client connected.
@@ -170,7 +170,7 @@ typedef struct
 typedef struct
 {
     int8_t log_state;          /**< the state to be used for logging state: 0 = off, 1 = external client connected */
-} PACKED DltUserControlMsgLogState;
+} DLT_PACKED DltUserControlMsgLogState;
 
 /**
  * This is the internal message content to get the number of lost messages reported to the daemon.
@@ -179,7 +179,7 @@ typedef struct
 {
     uint32_t overflow_counter;          /**< counts the number of lost messages */
     char apid[4];                        /**< application which lost messages */
-} PACKED DltUserControlMsgBufferOverflow;
+} DLT_PACKED DltUserControlMsgBufferOverflow;
 
 /**************************************************************************************************
 * The folowing functions are used shared between the user lib and the daemon implementation
