@@ -1,5 +1,4 @@
 /*
- * @licence app begin@
  * SPDX license identifier: MPL-2.0
  *
  * Copyright (C) 2011-2015, BMW AG
@@ -12,7 +11,6 @@
  * You can obtain one at http://mozilla.org/MPL/2.0/.
  *
  * For further information see http://www.genivi.org/.
- * @licence end@
  */
 
 /*!
@@ -274,9 +272,13 @@ int send_one(char *src, FiletransferOptions const *opts, int which)
         return -1;
     }
 
-    char *fdir = strndup(src, PATH_MAX);
-    MALLOC_ASSERT(fdir);
-    fdir = dirname(fdir);/*dirname overwrites its argument anyway */
+    char *src_copy = strndup(src, PATH_MAX);
+    MALLOC_ASSERT(src_copy);
+
+    /*dirname overwrites its argument anyway, */
+    /*but depending on argument returned address might change */
+    char *fdir = dirname(src_copy);
+
     char *dst_tosend;/*file which is going to be sent */
 
     char *rn = unique_name(src);/*new unique filename based on inode */
@@ -310,7 +312,7 @@ int send_one(char *src, FiletransferOptions const *opts, int which)
                     DLT_STRING(dst_tocompress));
             free(rn);
             free(dst_tocompress);
-            free(fdir);
+            free(src_copy);
             return -1;
         }
 
@@ -323,7 +325,7 @@ int send_one(char *src, FiletransferOptions const *opts, int which)
             free(rn);
             free(dst_tosend);
             free(dst_tocompress);
-            free(fdir);
+            free(src_copy);
             return -1;
         }
 
@@ -351,7 +353,7 @@ int send_one(char *src, FiletransferOptions const *opts, int which)
                     DLT_STRING(dst_tosend));
             free(rn);
             free(dst_tosend);
-            free(fdir);
+            free(src_copy);
             return -1;
         }
     }
@@ -364,7 +366,7 @@ int send_one(char *src, FiletransferOptions const *opts, int which)
 
     free(rn);
     free(dst_tosend);
-    free(fdir);
+    free(src_copy);
 
     return 0;
 }
@@ -767,12 +769,3 @@ void filetransfer_thread(void *v_conf)
         sleep(conf->Filetransfer.TimeDelay);
     }
 }
-
-void start_filetransfer(DltSystemConfiguration *conf)
-{
-    DLT_LOG(dltsystem, DLT_LOG_DEBUG, DLT_STRING("dlt-system-filetransfer, start."));
-    static pthread_attr_t t_attr;
-    static pthread_t pt;
-    pthread_create(&pt, &t_attr, (void *)filetransfer_thread, conf);
-    threads.threads[threads.count++] = pt;
-}
