@@ -151,13 +151,3 @@ void syslog_thread(void *v_conf)
 
     close (sock);
 }
-
-void start_syslog(DltSystemConfiguration *conf)
-{
-    DLT_LOG(dltsystem, DLT_LOG_DEBUG,
-            DLT_STRING("dlt-system-syslog, start syslog"));
-    static pthread_attr_t t_attr;
-    static pthread_t pt;
-    pthread_create(&pt, &t_attr, (void *)syslog_thread, conf);
-    threads.threads[threads.count++] = pt;
-}
